Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(298)

Unified Diff: chrome/browser/gtk/tab_contents_container_gtk.h

Issue 502073: Revert 34954 - Fix issue 11258: Linux: gracefully handle small browser window... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/gtk/slide_animator_gtk.cc ('k') | chrome/browser/gtk/tab_contents_container_gtk.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/gtk/tab_contents_container_gtk.h
===================================================================
--- chrome/browser/gtk/tab_contents_container_gtk.h (revision 34954)
+++ chrome/browser/gtk/tab_contents_container_gtk.h (working copy)
@@ -58,6 +58,15 @@
// get notified.
void TabContentsDestroyed(TabContents* contents);
+ // Implements our hack around a GtkFixed. The entire size of the GtkFixed is
+ // allocated to normal tab contents views, while the status bubble is
+ // informed of its parent and its parent's allocation (it makes a decision
+ // about layout later.)
+ static void OnFixedSizeAllocate(
+ GtkWidget* fixed,
+ GtkAllocation* allocation,
+ TabContentsContainerGtk* container);
+
// Handler for |floating_|'s "set-floating-position" signal. During this
// callback, we manually set the position of the status bubble.
static void OnSetFloatingPosition(
@@ -73,16 +82,16 @@
StatusBubbleGtk* status_bubble_;
// Top of the TabContentsContainerGtk widget hierarchy. A cross between a
// GtkBin and a GtkFixed, |floating_| has |expanded_| as its one "real" child,
// and the various things that hang off the bottom (status bubble, etc) have
// their positions manually set in OnSetFloatingPosition.
OwnedWidgetGtk floating_;
// We insert and remove TabContents GtkWidgets into this expanded_. This
// should not be a GtkVBox since there were errors with timing where the vbox
// was horizontally split with the top half displaying the current TabContents
// and bottom half displaying the loading page.
- GtkWidget* expanded_;
+ GtkWidget* fixed_;
DISALLOW_COPY_AND_ASSIGN(TabContentsContainerGtk);
};
« no previous file with comments | « chrome/browser/gtk/slide_animator_gtk.cc ('k') | chrome/browser/gtk/tab_contents_container_gtk.cc » ('j') | no next file with comments »
@@ -73,16 +82,16 @@
StatusBubbleGtk* status_bubble_;
// Top of the TabContentsContainerGtk widget hierarchy. A cross between a
- // GtkBin and a GtkFixed, |floating_| has |expanded_| as its one "real" child,
+ // GtkBin and a GtkFixed, |floating_| has |fixed_| as its one "real" child,
// and the various things that hang off the bottom (status bubble, etc) have
// their positions manually set in OnSetFloatingPosition.
@@ -73,16 +82,16 @@
// their positions manually set in OnSetFloatingPosition.
OwnedWidgetGtk floating_;
- // We insert and remove TabContents GtkWidgets into this expanded_. This
- // should not be a GtkVBox since there were errors with timing where the vbox
- // was horizontally split with the top half displaying the current TabContents
+ // We insert and remove TabContents GtkWidgets into this fixed_. This should
+ // not be a GtkVBox since there were errors with timing where the vbox was
+ // horizontally split with the top half displaying the current TabContents
// and bottom half displaying the loading page.

Powered by Google App Engine
This is Rietveld 408576698